
# Slot: id

Identifier of the activity unit. Should be in gocam namespace.

URI: [gocam:activity__id](https://w3id.org/gocam/activity__id)


## Domain and Range

None &#8594;  <sub>1..1</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [Activity](Activity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Comments:** | | Typically does not need to be exposed to end-user, this exists to allow activity flows |
| **Examples:** | | Example({
  'value': 'gomodel:63f809ec00000701',
  'description': 'A model representing tRNA repair and recycling'
}) |
